==> polymer-resource-pack-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/resourcepack/impl/client/rendering/PolymerResourcePack.java <==
package eu.pb4.polymer.resourcepack.impl.client.rendering;

import eu.pb4.polymer.common.impl.client.ClientUtils;
import eu.pb4.polymer.resourcepack.api.PolymerResourcePackUtils;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_3258;
import net.minecraft.class_3264;
import net.minecraft.class_3285;
import net.minecraft.class_3288;
import net.minecraft.class_3288.class_7680;
import net.minecraft.class_5352;
import net.minecraft.class_9224;
import net.minecraft.class_9225;
import net.minecraft.resource.*;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nullable;

import java.nio.file.Path;
import java.util.List;
import java.util.Optional;
import java.util.function.Consumer;

@ApiStatus.Internal
@Environment(EnvType.CLIENT)
public class PolymerResourcePack  {
    public static boolean generated = false;

    @Nullable
    public static class_3288.class_7680 setup() {
        Path outputPath = PolymerResourcePackUtils.getMainPath();
        if ((outputPath.toFile().exists() && generated) || PolymerResourcePackUtils.buildMain(outputPath)) {
            generated = true;
            return new class_3258.class_8615(outputPath.toFile());
        } else {
            return null;
        }
    }

    public static class Provider implements class_3285 {
        @Override
        public void method_14453(Consumer<class_3288> profileAdder) {
            if (PolymerResourcePackUtils.hasResources()) {
                var pack = PolymerResourcePack.setup();

                if (pack != null) {
                    profileAdder.accept(class_3288.method_45275(
                            new class_9224(ClientUtils.PACK_ID,
                            class_2561.method_43471("text.polymer.resource_pack.name"), class_5352.field_25348, Optional.empty()),
                            pack,
                            class_3264.field_14188,
                            new class_9225(PolymerResourcePackUtils.isRequired(), class_3288.class_3289.field_14280, false)
                    ));
                }
            }
        }
    }
}

==> polymer-resource-pack-0.14.4+1.21.10-sources.jar: eu/pb4/polymer/resourcepack/impl/client/rendering/PolymerResourcePack.java <==
package eu.pb4.polymer.resourcepack.impl.client.rendering;

import eu.pb4.polymer.common.impl.client.ClientUtils;
import eu.pb4.polymer.resourcepack.api.PolymerResourcePackUtils;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2561;
import net.minecraft.class_3258;
import net.minecraft.class_3264;
import net.minecraft.class_3285;
import net.minecraft.class_3288;
import net.minecraft.class_5352;
import net.minecraft.class_9224;
import net.minecraft.class_9225;
import net.minecraft.resource.*;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nullable;

import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Optional;
import java.util.function.Consumer;

@ApiStatus.Internal
@Environment(EnvType.CLIENT)
public class PolymerResourcePack {
    @Nullable
    private volatile static Path path = null;

    @Nullable
    public synchronized static class_3288.class_7680 setup() {
        if (path != null && Files.exists(path)) {
            return new class_3258.class_8615(path);
        }

        Path outputPath = PolymerResourcePackUtils.getMainPath();
        if (Files.exists(outputPath)) {
            try {
                Files.delete(outputPath);
            } catch (Throwable e) {
                // Failed to remove, change path to workaround one!
                outputPath = outputPath.resolveSibling(outputPath.getFileName().toString() + "_client.zip");
                if (Files.exists(outputPath)) {
                    try {
                        Files.delete(outputPath);
                    } catch (Throwable f2) {
                        // AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
                        // I hate windows
                    }
                }
            }
        }

        if (PolymerResourcePackUtils.buildMain(outputPath)) {
            path = outputPath;
            return new class_3258.class_8615(outputPath);
        } else {
            return null;
        }
    }

    public static class Provider implements class_3285 {
        @Override
        public void method_14453(Consumer<class_3288> profileAdder) {
            if (PolymerResourcePackUtils.hasResources()) {
                var pack = PolymerResourcePack.setup();

                if (pack != null) {
                    profileAdder.accept(class_3288.method_45275(
                            new class_9224(ClientUtils.PACK_ID,
                            class_2561.method_43471("text.polymer.resource_pack.name"), class_5352.field_25348, Optional.empty()),
                            pack,
                            class_3264.field_14188,
                            new class_9225(PolymerResourcePackUtils.isRequired(), class_3288.class_3289.field_14280, false)
                    ));
                }
            }
        }
    }
}
